@@ -11,7 +11,6 @@
 <a href="https://plumberserver.com/plotters-docs/plotters">
     <img style="display: inline! important" src="https://img.shields.io/badge/docs-development-lightgrey.svg"></img>
 </a>
-
 <a href="https://travis-ci.org/38/plotters">
     <img style="display: inline! important" src="https://travis-ci.org/38/plotters.svg?branch=master"></img>
 </a>
@@ -19,11 +18,13 @@
 Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends,
 including bitmap, vector graph, piston window and WebAssembly.
 
+- You can try Plotters with Jupyter notebook, or view [here](https://plotters-rs.github.io/plotters-doc-data/evcxr-jupyter-integration.html) for the static HTML version.
+
 ## Gallery
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/sample.png">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/sample.png" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/sample.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/sample.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Multiple Plot
@@ -32,8 +33,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/stock.png">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/stock.png" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/stock.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/stock.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Candlestick Plot
@@ -42,8 +43,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/histogram.png">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/histogram.png" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/histogram.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/histogram.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
        Histogram
@@ -52,8 +53,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/0.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/0.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Simple Chart
@@ -61,8 +62,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/mandelbrot.png">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/mandelbrot.png" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/mandelbrot.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/mandelbrot.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Mandelbrot set
@@ -72,8 +73,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/evcxr_animation.gif">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/evcxr_animation.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Jupyter Support
@@ -81,8 +82,8 @@ including bitmap, vector graph, piston window and WebAssembly.
 </div>
 
 <div class="galleryItem">
-    <a href="https://raw.githubusercontent.com/38/plotters-doc-data/master/plotters-piston.gif">
-        <img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/plotters-piston.gif" class="galleryItem"></img>
+    <a href="https://plotters-rs.github.io/plotters-doc-data/plotters-piston.gif">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/plotters-piston.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
         Realtime Rendering
@@ -90,14 +91,25 @@ including bitmap, vector graph, piston window and WebAssembly.
     </div>
 </div>
 
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/normal-dist.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/normal-dist.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Histogram with Scatter
+        <a href="https://github.com/38/plotters/blob/master/examples/normal-dist.rs">[code]</a>
+    </div>
+</div>
+
 
 ## Table of Contents
   * [Gallery](#gallery)
   * [Quick Start](#quick-start)
   * [Trying with Jupyter evcxr Kernel Interactively](#trying-with-jupyter-evcxr-kernel-interactively)
+  * [Interactive Tutorial with Jupyter Notebook](#interactive-tutorial-with-jupyter-notebook)
   * [Plotting in Rust](#plotting-in-rust)
   * [Plotting on HTML5 canvas with WASM Backend](#plotting-on-html5-canvas-with-wasm-backend)
-  * [What types of figure are supported?](#what-types-of-figure-are-supported-)
+  * [What types of figure are supported?](#what-types-of-figure-are-supported)
   * [Concepts by examples](#concepts-by-examples)
     + [Drawing Backends](#drawing-backends)
     + [Drawing Area](#drawing-area)
@@ -106,14 +118,14 @@ including bitmap, vector graph, piston window and WebAssembly.
     + [Chart Context](#chart-context)
   * [Misc](#misc)
     + [Development Version](#development-version)
-    + [Reducing Depending Libraries && Turning Off Backends](#reducing-depending-libraries----turning-off-backends)
+    + [Reducing Depending Libraries && Turning Off Backends](#reducing-depending-libraries--turning-off-backends)
 
 ## Quick Start
 
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
-[depedencies]
-plotters = "^0.2.1"
+[dependencies]
+plotters = "^0.2.2"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -148,7 +160,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/0.png)
+![](https://plotters-rs.github.io/plotters-doc-data/0.png)
 
 
 ## Trying with Jupyter evcxr Kernel Interactively
@@ -190,7 +202,27 @@ let figure = evcxr_figure((640, 480), |root| {
 figure
 ```
 
-<img src="https://raw.githubusercontent.com/38/plotters-doc-data/master/evcxr_animation.gif" width="450px"></img>
+<img src="https://plotters-rs.github.io/plotters-doc-data/evcxr_animation.gif" width="450px"></img>
+
+## Interactive Tutorial with Jupyter Notebook
+
+*This tutorial is now working in progress and isn't complete*
+
+Thanks to the evcxr, now we have an interactive tutorial for Plotters!
+To use the interactive notebook, you must have Jupyter and evcxr installed on your computer.
+Follow the instruction on [this page](https://github.com/google/evcxr/tree/master/evcxr_jupyter) below to install it.
+
+After that, you should be able to start your Jupyer server locally and load the tutorial!
+
+```bash
+git clone https://github.com/38/plotters-doc-data
+cd plotteres-doc-data
+jupyter notebook
+```
+
+And select the notebook called `evcxr-jupyter-integration.ipynb`.
+
+Also, there's a static HTML version of this notebook available at the [this location](https://plumberserver.com/plotters-docs/evcxr-jupyter-integration.html)
 
 ## Plotting in Rust
 
@@ -248,7 +280,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/1.png)
+![](https://plotters-rs.github.io/plotters-doc-data/1.png)
 
 ### Drawing Area
 Plotters uses a concept called drawing area for layout purpose.
@@ -272,7 +304,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/2.png)
+![](https://plotters-rs.github.io/plotters-doc-data/2.png)
 
 ### Elements
 
@@ -299,7 +331,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/3.png)
+![](https://plotters-rs.github.io/plotters-doc-data/3.png)
 
 ### Composable Elements
 
@@ -336,7 +368,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/4.png)
+![](https://plotters-rs.github.io/plotters-doc-data/4.png)
 
 ### Chart Context
 
@@ -391,7 +423,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 ```
 
-![](https://raw.githubusercontent.com/38/plotters-doc-data/master/5.png)
+![](https://plotters-rs.github.io/plotters-doc-data/5.png)
 
 ## Misc
 
@@ -454,7 +486,7 @@ pub use crate::drawing::create_mocked_drawing_area;
 
 /// The module imports the most commonly used types and modules in Plotters
 pub mod prelude {
-    pub use crate::chart::{ChartBuilder, ChartContext};
+    pub use crate::chart::{ChartBuilder, ChartContext, SeriesLabelPosition};
     pub use crate::coord::{
         CoordTranslate, LogCoord, LogRange, LogScalable, Ranged, RangedCoord, RangedCoordf32,
         RangedCoordf64, RangedCoordi32, RangedCoordi64, RangedCoordu32, RangedCoordu64,
