@@ -1,5 +1,6 @@
 use super::palette::Palette;
-/// The abstraction of a color
+use super::ShapeStyle;
+
 use std::marker::PhantomData;
 
 /// Any color representation
@@ -23,6 +24,14 @@ pub trait Color {
         let a = self.alpha();
         RGBAColor(r, g, b, a)
     }
+
+    /// Make a filled style form the color
+    fn filled(&self) -> ShapeStyle
+    where
+        Self: Sized,
+    {
+        Into::<ShapeStyle>::into(self).filled()
+    }
 }
 
 /// The RGBA representation of the color, Plotters use RGBA as the internal representation
